package com.xy.service;

import com.xy.utils.AliOssUtil;
import com.xy.utils.R;
import com.xy.vo.PolicyVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/***
 * 对象存储实现类
 * @author 谭斌
 * @date 2023/1/9 11:22
 */
@Api(tags = "对象存储")
@Slf4j
@Service
@RequiredArgsConstructor
public class OssServiceImpl implements OssService {

    private final AliOssService aliOssService;

    @ApiOperation(value = "policy获取", notes = "阿里云OSS服务端签名后前端直传方式获取policy")
    @GetMapping("aliOSS/policy")
    public R<PolicyVo> getPolicy(@ApiParam(name = "dir", value = "上传目录", required = false) @RequestParam(value = "dir", required = false) String dir) {
        return aliOssService.getPolicy(dir);
    }

    @ApiOperation(value = "获取指定目录下的文件列表", notes = "获取指定目录下的文件列表")
    @GetMapping("aliOSS/listFilesInDir")
    public R<List<AliOssUtil.FileInfo>> listFilesInDir(@ApiParam(name = "dir", value = "目录", required = false) @RequestParam(value = "dir", required = false) String dir) {
         List<AliOssUtil.FileInfo> files = AliOssUtil.listFilesInDir(dir, null);
        files.forEach(file -> {
            System.out.println(String.format("%s | 大小: %dB | 修改时间: %tF",
                    file.getFileName(),
                    file.getSize(),
                    file.getUpdateTime()));
        });

        return R.ok(files);
    }
}
